﻿-- Author      : RisM
-- Create Date : 9/21/2009 11:52:56 PM

local SpeakinSpell = LibStub("AceAddon-3.0"):GetAddon("SpeakinSpell")
local L	= LibStub("AceLocale-3.0"):GetLocale("SpeakinSpell", false)
local LDB = LibStub:GetLibrary("LibDataBroker-1.1")
local LDBIcon = LDB and LibStub("LibDBIcon-1.0", true)

SpeakinSpell:PrintLoading("gui/minimapbutton.lua")


-------------------------------------------------------------------------------
-- SetIcon extension to LDBIcon
-------------------------------------------------------------------------------


function LDBIcon:SetIcon(name, newicon)
	local button = LDBIcon.objects[name]
	button.icon:SetTexture(newicon)
	
	--TODOFUTURE: is it possible to get the icon to change in the Titan Panel also?
	
	--[[ this doesn't seem to have any effect
	local dataobj = {
		icon = newicon
	}
	LDB.callbacks:Fire("LibDataBroker_AttributeChanged_"..name.."_icon", "icon", newicon, dataobj)
	--]]
	
	-- copied out of Titan\LDBtoTitan.lua, this is the fragment of code I wanted the callback to fire
	-- this is from the function TitanLDBIconUpdate
	-- this code fragment appears to work, I guess, except that the icon is not redrawn as desired
	--[[ mothballed for now since it's not having any effect
	if TitanPlugins and TitanPanelButton_SetButtonIcon then
		--SpeakinSpell:Print("updating Titan")
 		TitanPlugins["LDBT_"..name].icon = value;
 		TitanPanelButton_SetButtonIcon("LDBT_"..name);
	else
		--SpeakinSpell:Print("can't find Titan")
	end
	--]]
end


-------------------------------------------------------------------------------
-- MINIMAP BUTTON SUPPORT
-------------------------------------------------------------------------------


function SpeakinSpell:MinimapButton_Create()
	local funcname = "MinimapButton_Create"
	
	if not (LDB and LDBIcon) then
		return
	end
	
	-- define which icons we'll use
	SpeakinSpell.iconpaths = {
		ON = "Interface\\Icons\\Ability_Warrior_BattleShout", --recognizable i guess
		OFF = "Interface\\Icons\\Ability_Rogue_Disguise", --this is OK for off
	}
	
	-- LDB launcher
	--self:DebugMsg(funcname,"entry")
	SpeakinSpell.Minimap = {
		--[[ SpeakinSpell.Minimap.Icon has moved to SpeakinSpellSavedData.MinimapIcon
		Icon = {
			hide = false,
			minimapPos = 220,
			radius = 80,
		},
		--]]
		Launcher = LDB:NewDataObject("SpeakinSpell", {
			type = "launcher",
			icon = SpeakinSpell.iconpaths.ON,
			OnClick = function(clickedframe, button)
				SpeakinSpell:MinimapButton_OnClick(clickedframe, button)
			end,
			OnTooltipShow = function(tt)
				local line = "SpeakinSpell"
				if SpeakinSpellSavedData.EnableAllMessages then
					line = line..tostring(SpeakinSpell.Colors.Minimap.ON)..L[" is ON"]
				else
					line = line..tostring(SpeakinSpell.Colors.Minimap.OFF)..L[" is OFF"]
				end
				tt:AddLine(line)
				tt:AddLine( tostring(SpeakinSpell.Colors.Minimap.Click) .. L["Click|r to toggle SpeakinSpell on/off"])
				tt:AddLine( tostring(SpeakinSpell.Colors.Minimap.Click) .. L["Right-click|r to open the options"])
			end,
		}),
		Registered = false,
	}

	-- show a different icon to indicate on/off status
	-- we assumed ON above, but init to OFF if we're disabled
	-- TODOFUTURE: for now, this causes an issue with the titan panel integration
	--		see failed experiments in LDBIcon:SetIcon above
	--		For now, always initialize to the ON icon, for use in the Titan Panel
	--		then call a Refresh later to update the minimap button accordingly
--	if not SpeakinSpellSavedData.EnableAllMessages then
--		SpeakinSpell.Minimap.Launcher.icon = SpeakinSpell.iconpaths.OFF
--	end
	
	if SpeakinSpellSavedData.ShowMinimapButton then 
		self:MinimapButton_Register()
		
		-- TODOFUTURE: this should not be required after Titan panel support is fixed - see comments above
		if not SpeakinSpellSavedData.EnableAllMessages then
			LDBIcon:SetIcon("SpeakinSpell", SpeakinSpell.iconpaths.OFF)
		end
	end
end


function SpeakinSpell:MinimapButton_Register()
	local funcname = "MinimapButton_Register"
	--self:DebugMsg(funcname,"Register")
	SpeakinSpell.Minimap.Registered = true
	
	-- from instructions on http://wow.curse.com/downloads/wow-addons/details/libdbicon-1-0.aspx
	-- icon:Register("MyLDB", myLDB, savedVarTable)
	-- myLDB objdect is the Minimap.Launcher
	-- saved vars for the position of the icon is in SpeakinSpellSavedData.MinimapIcon
	
	LDBIcon:Register("SpeakinSpell", SpeakinSpell.Minimap.Launcher, SpeakinSpellSavedData.MinimapIcon)
end


function SpeakinSpell:MinimapButton_OnClick(clickedframe, button)
	if button == "RightButton" then 
		SpeakinSpell:ShowOptions_Toggle() 
	else 
		SpeakinSpellSavedData.EnableAllMessages = not SpeakinSpellSavedData.EnableAllMessages
		self:MinimapButton_Refresh()
		self:RefreshFrame("General")
	end
end


function SpeakinSpell:MinimapButton_Refresh()
	local funcname = "MinimapButton_Refresh"

	if SpeakinSpellSavedData.ShowMinimapButton then 
		if not SpeakinSpell.Minimap.Registered then
			self:MinimapButton_Register()
		end
		
		-- make sure the button is showing
		--self:DebugMsg(funcname, "show")
		LDBIcon:Show("SpeakinSpell") 
		self.RuntimeData.MinimapShowing = true

		-- show a different icon to indicate on/off status
		local icon = SpeakinSpell.iconpaths.OFF
		if SpeakinSpellSavedData.EnableAllMessages then
			icon = SpeakinSpell.iconpaths.ON
		end
		--self:DebugMsg(funcname, "setting icon:"..tostring(icon))
		LDBIcon:SetIcon("SpeakinSpell", icon) 
	else 
		if not self.RuntimeData.MinimapShowing then
			return
		end
		-- make sure the button is hidden
		--self:DebugMsg(funcname, "hide")
		LDBIcon:Hide("SpeakinSpell")
		self.RuntimeData.MinimapShowing = false 
	end
end



function SpeakinSpell:MinimapButton_Show(show)
	SpeakinSpellSavedData.ShowMinimapButton = show
	self:MinimapButton_Refresh()
end

